@@ -342,7 +342,7 @@ void EditorItemManager::save()
 
     if (d->mItem.isValid()) {   // A valid item. Means we're modifying.
         Q_ASSERT(d->mItem.parentCollection().isValid());
-        KCalCore::Incidence::Ptr oldPayload = CalendarSupport::incidence(d->mPrevItem);
+        KCalendarCore::Incidence::Ptr oldPayload = CalendarSupport::incidence(d->mPrevItem);
         if (d->mItem.parentCollection() == d->mItemUi->selectedCollection()
             || d->mItem.storageCollectionId() == d->mItemUi->selectedCollection().id()) {
             d->mChanger->modifyIncidence(d->mItem, oldPayload);
@@ -353,8 +353,8 @@ void EditorItemManager::save()
             // ETM and the KSelectionProxyModel has a bug wrt collections moves, so this is disabled.
             // To test this, enable the collection combo-box and remove the following assert.
             qCDebug(INCIDENCEEDITOR_LOG) << "Moving from"
-                                            << d->mItem.parentCollection().id() << "to"
-                                            << d->mItemUi->selectedCollection().id();
+                                         << d->mItem.parentCollection().id() << "to"
+                                         << d->mItemUi->selectedCollection().id();
 
             if (d->mItemUi->isDirty()) {
                 d->mChanger->modifyIncidence(d->mItem, oldPayload);
@@ -370,7 +370,7 @@ void EditorItemManager::save()
             Q_EMIT itemSaveFinished(EditorItemManager::Modify);
         } else {
             Q_ASSERT(d->mItemUi->selectedCollection().isValid());
-            KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence(d->mItem);
+            KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(d->mItem);
             d->mChanger->createIncidence(incidence, d->mItemUi->selectedCollection());
         }
     }
