@@ -198,7 +198,7 @@ void IncidenceAttachment::removeSelectedAttachments()
         return;
     }
 
-    QString labelsStr = labels.join(QStringLiteral("<nl/>"));
+    QString labelsStr = labels.join(QLatin1String("<nl/>"));
 
     if (KMessageBox::questionYesNo(
             nullptr,
@@ -380,6 +380,9 @@ void IncidenceAttachment::slotSelectionChanged()
 
 void IncidenceAttachment::handlePasteOrDrop(const QMimeData *mimeData)
 {
+    if (!mimeData) {
+        return;
+    }
     QList<QUrl> urls;
     bool probablyWeHaveUris = false;
     QStringList labels;
@@ -404,14 +407,22 @@ void IncidenceAttachment::handlePasteOrDrop(const QMimeData *mimeData)
         //urls = QList<QUrl>::fromMimeData( mimeData, &metadata );
         probablyWeHaveUris = true;
         labels
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             = metadata[QStringLiteral("labels")].split(QLatin1Char(':'), QString::SkipEmptyParts);
+#else
+            = metadata[QStringLiteral("labels")].split(QLatin1Char(':'), Qt::SkipEmptyParts);
+#endif
         const QStringList::Iterator end(labels.end());
         for (QStringList::Iterator it = labels.begin(); it != end; ++it) {
             *it = QUrl::fromPercentEncoding((*it).toLatin1());
         }
     } else if (mimeData->hasText()) {
         const QString text = mimeData->text();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QStringList lst = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#else
+        QStringList lst = text.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#endif
         urls.reserve(lst.count());
         QStringList::ConstIterator end(lst.constEnd());
         for (QStringList::ConstIterator it = lst.constBegin(); it != end; ++it) {
@@ -595,13 +606,13 @@ void IncidenceAttachment::addUriAttachment(const QString &uri, const QString &mi
         item->setUri(uri);
         item->setLabel(label);
         if (mimeType.isEmpty()) {
-            if (uri.startsWith(QStringLiteral("uid:"))) {
+            if (uri.startsWith(QLatin1String("uid:"))) {
                 item->setMimeType(QStringLiteral("text/directory"));
-            } else if (uri.startsWith(QStringLiteral("kmail:"))) {
+            } else if (uri.startsWith(QLatin1String("kmail:"))) {
                 item->setMimeType(QStringLiteral("message/rfc822"));
-            } else if (uri.startsWith(QStringLiteral("urn:x-ical"))) {
+            } else if (uri.startsWith(QLatin1String("urn:x-ical"))) {
                 item->setMimeType(QStringLiteral("text/calendar"));
-            } else if (uri.startsWith(QStringLiteral("news:"))) {
+            } else if (uri.startsWith(QLatin1String("news:"))) {
                 item->setMimeType(QStringLiteral("message/news"));
             } else {
                 QMimeDatabase db;
