@@ -38,8 +38,11 @@
 #include <Akonadi/Contact/ContactGroupExpandJob>
 #include <Akonadi/Contact/ContactGroupSearchJob>
 #include <Akonadi/Contact/EmailAddressSelectionDialog>
+#include <Akonadi/Contact/AbstractEmailAddressSelectionDialog>
 
 #include <KEmailAddress>
+#include <KPluginFactory>
+#include <KPluginLoader>
 #include <KCalUtils/Stringify>
 
 #include "incidenceeditor_debug.h"
@@ -127,7 +130,11 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     connect(mUi->mOrganizerCombo, qOverload<const QString &>(&QComboBox::activated),
             this, &IncidenceAttendee::slotOrganizerChanged);
     */
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mUi->mOrganizerCombo, qOverload<int>(&QComboBox::currentIndexChanged),
+#else
+    connect(mUi->mOrganizerCombo, qOverload<int, const QString &>(&QComboBox::currentIndexChanged),
+#endif
             this, &IncidenceAttendee::checkDirtyStatus);
 
     connect(mDateTime, &IncidenceDateTime::startDateChanged, this,
@@ -451,27 +458,42 @@ void IncidenceAttendee::expandResult(KJob *job)
         dataModel()->removeRow(row);
         for (const KContacts::Addressee &member : groupMembers) {
             KCalendarCore::Attendee newAt(member.realName(), member.preferredEmail(),
-                                              attendee.RSVP(),
-                                              attendee.status(),
-                                              attendee.role(),
-                                              member.uid());
+                                          attendee.RSVP(),
+                                          attendee.status(),
+                                          attendee.role(),
+                                          member.uid());
             dataModel()->insertAttendee(row, newAt);
         }
     }
 }
 
+void IncidenceAttendee::insertAddresses(const KContacts::Addressee::List &list)
+{
+    for (const KContacts::Addressee &contact : list) {
+        insertAttendeeFromAddressee(contact);
+    }
+}
+
 void IncidenceAttendee::slotSelectAddresses()
 {
-    QPointer<Akonadi::EmailAddressSelectionDialog> dialog = new Akonadi::EmailAddressSelectionDialog(mParentWidget);
+    QPointer<Akonadi::AbstractEmailAddressSelectionDialog> dialog;
+    KPluginLoader loader(QStringLiteral("akonadi/emailaddressselectionldapdialogplugin"));
+    KPluginFactory *factory = loader.factory();
+    if (factory) {
+        dialog = factory->create<Akonadi::AbstractEmailAddressSelectionDialog>(mParentWidget);
+    } else {
+        dialog = new Akonadi::EmailAddressSelectionDialog(mParentWidget);
+    }
     dialog->view()->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
-    dialog->setWindowTitle(i18n("Select Attendees"));
+    dialog->setWindowTitle(i18nc("@title:window", "Select Attendees"));
+    connect(dialog.data(), &Akonadi::AbstractEmailAddressSelectionDialog::insertAddresses, this, &IncidenceEditorNG::IncidenceAttendee::insertAddresses);
     if (dialog->exec() == QDialog::Accepted) {
         const Akonadi::EmailAddressSelection::List list = dialog->selectedAddresses();
         for (const Akonadi::EmailAddressSelection &selection : list) {
             if (selection.item().hasPayload<KContacts::ContactGroup>()) {
                 Akonadi::ContactGroupExpandJob *job
-                        = new Akonadi::ContactGroupExpandJob(
-                            selection.item().payload<KContacts::ContactGroup>(), this);
+                    = new Akonadi::ContactGroupExpandJob(
+                          selection.item().payload<KContacts::ContactGroup>(), this);
                 connect(job, &Akonadi::ContactGroupExpandJob::result, this,
                         &IncidenceAttendee::expandResult);
                 KCalendarCore::Attendee::PartStat partStat = KCalendarCore::Attendee::NeedsAction;
@@ -479,10 +501,10 @@ void IncidenceAttendee::slotSelectAddresses()
 
                 int pos = 0;
                 KCalendarCore::Attendee newAt(selection.name(),
-                                                  selection.email(),
-                                                  rsvp,
-                                                  partStat,
-                                                  KCalendarCore::Attendee::ReqParticipant);
+                                              selection.email(),
+                                              rsvp,
+                                              partStat,
+                                              KCalendarCore::Attendee::ReqParticipant);
                 dataModel()->insertAttendee(pos, newAt);
 
                 mExpandGroupJobs.insert(job, newAt.uid());
@@ -793,10 +815,10 @@ void IncidenceAttendee::insertAttendeeFromAddressee(const KContacts::Addressee &
         rsvp = false;
     }
     KCalendarCore::Attendee newAt(a.realName(), a.preferredEmail(),
-                                                         rsvp,
-                                                         partStat,
-                                                         KCalendarCore::Attendee::ReqParticipant,
-                                                         a.uid());
+                                  rsvp,
+                                  partStat,
+                                  KCalendarCore::Attendee::ReqParticipant,
+                                  a.uid());
     if (pos < 0) {
         pos = dataModel()->rowCount() - 1;
     }
@@ -868,10 +890,10 @@ void IncidenceAttendee::slotOrganizerChanged(const QString &newOrganizer)
         if (newOrganizerAttendee == -1) {
             bool rsvp = !iAmOrganizer(); // if it is the user, don't make him rsvp.
             KCalendarCore::Attendee::PartStat status = iAmOrganizer() ? KCalendarCore::Attendee::Accepted
-                                                  : KCalendarCore::Attendee::NeedsAction;
+                                                       : KCalendarCore::Attendee::NeedsAction;
 
             KCalendarCore::Attendee newAt(name, email, rsvp, status,
-                                       KCalendarCore::Attendee::ReqParticipant);
+                                          KCalendarCore::Attendee::ReqParticipant);
 
             mDataModel->insertAttendee(mDataModel->rowCount(), newAt);
         }
