@@ -21,7 +21,7 @@
 #include "incidencecompletionpriority.h"
 #include "ui_dialogdesktop.h"
 
-#include <KCalCore/Todo>
+#include <KCalendarCore/Todo>
 
 using namespace IncidenceEditorNG;
 
@@ -73,7 +73,11 @@ IncidenceCompletionPriority::IncidenceCompletionPriority(Ui::EventOrTodoDesktop
     connect(d->mUi->mCompletionSlider, qOverload<int>(&QSlider::valueChanged), this, [this](int val) {
         d->sliderValueChanged(val);
     });
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(d->mUi->mPriorityCombo, qOverload< int>(&QComboBox::currentIndexChanged), this, &IncidenceCompletionPriority::checkDirtyStatus);
+#else
+    connect(d->mUi->mPriorityCombo, qOverload<int, const QString &>(&QComboBox::currentIndexChanged), this, &IncidenceCompletionPriority::checkDirtyStatus);
+#endif
 }
 
 IncidenceCompletionPriority::~IncidenceCompletionPriority()
@@ -81,13 +85,13 @@ IncidenceCompletionPriority::~IncidenceCompletionPriority()
     delete d;
 }
 
-void IncidenceCompletionPriority::load(const KCalCore::Incidence::Ptr &incidence)
+void IncidenceCompletionPriority::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
     mLoadedIncidence = incidence;
 
     // TODO priority might be valid for other incidence types as well
     // only for Todos
-    KCalCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalCore::Todo>();
+    KCalendarCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalendarCore::Todo>();
     if (todo == nullptr) {
         mWasDirty = false;
         return;
@@ -110,11 +114,11 @@ void IncidenceCompletionPriority::load(const KCalCore::Incidence::Ptr &incidence
     mWasDirty = false;
 }
 
-void IncidenceCompletionPriority::save(const KCalCore::Incidence::Ptr &incidence)
+void IncidenceCompletionPriority::save(const KCalendarCore::Incidence::Ptr &incidence)
 {
     // TODO priority might be valid for other incidence types as well
     // only for Todos
-    KCalCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalCore::Todo>(incidence);
+    KCalendarCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalendarCore::Todo>(incidence);
     if (todo == nullptr) {
         return;
     }
@@ -131,7 +135,7 @@ void IncidenceCompletionPriority::save(const KCalCore::Incidence::Ptr &incidence
 
 bool IncidenceCompletionPriority::isDirty() const
 {
-    KCalCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalCore::Todo>();
+    KCalendarCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalendarCore::Todo>();
 
     if (!todo) {
         return false;
