@@ -554,12 +554,23 @@ void IncidenceDateTime::load(const KCalendarCore::Event::Ptr &event, bool isTemp
             &IncidenceDateTime::updateStartTime);                                                         // When editing with any key except up/down
     connect(mUi->mStartDateEdit, &KDateComboBox::dateChanged, this,
             &IncidenceDateTime::updateStartDate);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mUi->mTimeZoneComboStart,
             static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int)>(&IncidenceEditorNG::
                                                                              KTimeZoneComboBox::
                                                                              currentIndexChanged),
             this,
             &IncidenceDateTime::updateStartSpec);
+#else
+    connect(mUi->mTimeZoneComboStart,
+            static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int, const QString &)>(&IncidenceEditorNG::
+                                                                             KTimeZoneComboBox::
+                                                                             currentIndexChanged),
+            this,
+            &IncidenceDateTime::updateStartSpec);
+#endif
+
+
     // End time
     connect(mUi->mEndTimeEdit, &KTimeComboBox::timeChanged, this,
             &IncidenceDateTime::checkDirtyStatus);
@@ -573,13 +584,21 @@ void IncidenceDateTime::load(const KCalendarCore::Event::Ptr &event, bool isTemp
             &IncidenceDateTime::endTimeChanged);
     connect(mUi->mEndDateEdit, &KDateComboBox::dateChanged, this,
             &IncidenceDateTime::endDateChanged);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mUi->mTimeZoneComboEnd,
             static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int)>(&IncidenceEditorNG::
                                                                              KTimeZoneComboBox::
                                                                              currentIndexChanged),
             this,
             &IncidenceDateTime::checkDirtyStatus);
-
+#else
+    connect(mUi->mTimeZoneComboEnd,
+            static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int, const QString &)>(&IncidenceEditorNG::
+                                                                             KTimeZoneComboBox::
+                                                                             currentIndexChanged),
+            this,
+            &IncidenceDateTime::checkDirtyStatus);
+#endif
     mUi->mWholeDayCheck->setChecked(event->allDay());
     enableTimeEdits();
 
@@ -622,13 +641,21 @@ void IncidenceDateTime::load(const KCalendarCore::Journal::Ptr &journal, bool is
             &IncidenceDateTime::updateStartTime);
     connect(mUi->mStartDateEdit, &KDateComboBox::dateChanged, this,
             &IncidenceDateTime::updateStartDate);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mUi->mTimeZoneComboStart,
             static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int)>(&IncidenceEditorNG::
                                                                              KTimeZoneComboBox::
                                                                              currentIndexChanged),
             this,
             &IncidenceDateTime::updateStartSpec);
-
+#else
+    connect(mUi->mTimeZoneComboStart,
+            static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int, const QString &)>(&IncidenceEditorNG::
+                                                                             KTimeZoneComboBox::
+                                                                             currentIndexChanged),
+            this,
+            &IncidenceDateTime::updateStartSpec);
+#endif
     mUi->mWholeDayCheck->setChecked(journal->allDay());
     enableTimeEdits();
 
@@ -680,12 +707,22 @@ void IncidenceDateTime::load(const KCalendarCore::Todo::Ptr &todo, bool isTempla
             &IncidenceDateTime::updateStartTime);
     connect(mUi->mStartTimeEdit, &KTimeComboBox::timeEdited, this,
             &IncidenceDateTime::checkDirtyStatus);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mUi->mTimeZoneComboStart,
             static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int)>(&IncidenceEditorNG::
                                                                              KTimeZoneComboBox::
                                                                              currentIndexChanged),
             this,
             &IncidenceDateTime::checkDirtyStatus);
+#else
+    connect(mUi->mTimeZoneComboStart,
+            static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int, const QString &)>(&IncidenceEditorNG::
+                                                                             KTimeZoneComboBox::
+                                                                             currentIndexChanged),
+            this,
+            &IncidenceDateTime::checkDirtyStatus);
+
+#endif
 
     connect(mUi->mEndCheck, &QCheckBox::toggled, this, &IncidenceDateTime::enableEndEdit);
     connect(mUi->mEndCheck, &QCheckBox::toggled, this, &IncidenceDateTime::endDateTimeToggled);
@@ -699,13 +736,21 @@ void IncidenceDateTime::load(const KCalendarCore::Todo::Ptr &todo, bool isTempla
             &IncidenceDateTime::endDateChanged);
     connect(mUi->mEndTimeEdit, &KTimeComboBox::timeChanged, this,
             &IncidenceDateTime::endTimeChanged);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mUi->mTimeZoneComboEnd,
             static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int)>(&IncidenceEditorNG::
                                                                              KTimeZoneComboBox::
                                                                              currentIndexChanged),
             this,
             &IncidenceDateTime::checkDirtyStatus);
-
+#else
+    connect(mUi->mTimeZoneComboEnd,
+            static_cast<void (IncidenceEditorNG::KTimeZoneComboBox::*)(int, const QString &)>(&IncidenceEditorNG::
+                                                                             KTimeZoneComboBox::
+                                                                             currentIndexChanged),
+            this,
+            &IncidenceDateTime::checkDirtyStatus);
+#endif
     const QDateTime rightNow = QDateTime::currentDateTime();
 
     if (isTemplate) {
@@ -826,9 +871,9 @@ void IncidenceDateTime::updateStartToolTips()
     if (mUi->mStartCheck->isChecked()) {
         QString datetimeStr
             = KCalUtils::IncidenceFormatter::dateTimeToString(
-            currentStartDateTime(),
-            mUi->mWholeDayCheck->isChecked(),
-            false);
+                  currentStartDateTime(),
+                  mUi->mWholeDayCheck->isChecked(),
+                  false);
         mUi->mStartDateEdit->setToolTip(i18n("Starts: %1", datetimeStr));
         mUi->mStartTimeEdit->setToolTip(i18n("Starts: %1", datetimeStr));
     } else {
@@ -842,9 +887,9 @@ void IncidenceDateTime::updateEndToolTips()
     if (mUi->mStartCheck->isChecked()) {
         QString datetimeStr
             = KCalUtils::IncidenceFormatter::dateTimeToString(
-            currentEndDateTime(),
-            mUi->mWholeDayCheck->isChecked(),
-            false);
+                  currentEndDateTime(),
+                  mUi->mWholeDayCheck->isChecked(),
+                  false);
         if (mLoadedIncidence->type() == KCalendarCore::Incidence::TypeTodo) {
             mUi->mEndDateEdit->setToolTip(i18n("Due on: %1", datetimeStr));
             mUi->mEndTimeEdit->setToolTip(i18n("Due on: %1", datetimeStr));
