@@ -33,13 +33,12 @@
 
 using namespace IncidenceEditorNG;
 
-SchedulingDialog::SchedulingDialog(const QDate &startDate, const QTime &startTime, int duration,
-                                   ConflictResolver *resolver, QWidget *parent)
+SchedulingDialog::SchedulingDialog(const QDate &startDate, const QTime &startTime, int duration, ConflictResolver *resolver, QWidget *parent)
     : QDialog(parent)
     , mResolver(resolver)
     , mPeriodModel(new CalendarSupport::FreePeriodModel(this))
 {
-    setWindowTitle(i18n("Scheduling"));
+    setWindowTitle(i18nc("@title:window", "Scheduling"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QWidget *w = new QWidget(this);
     setupUi(w);
@@ -103,8 +102,7 @@ SchedulingDialog::~SchedulingDialog()
 {
 }
 
-void SchedulingDialog::slotUpdateIncidenceStartEnd(const QDateTime &startDateTime,
-                                                   const QDateTime &endDateTime)
+void SchedulingDialog::slotUpdateIncidenceStartEnd(const QDateTime &startDateTime, const QDateTime &endDateTime)
 {
     mVisualWidget->slotUpdateIncidenceStartEnd(startDateTime, endDateTime);
 }
@@ -113,13 +111,13 @@ void SchedulingDialog::fillCombos()
 {
 // Note: we depend on the following order
     mRolesCombo->addItem(QIcon::fromTheme(QStringLiteral("meeting-participant")),
-                         KCalUtils::Stringify::attendeeRole(KCalCore::Attendee::ReqParticipant));
+                         KCalUtils::Stringify::attendeeRole(KCalendarCore::Attendee::ReqParticipant));
     mRolesCombo->addItem(QIcon::fromTheme(QStringLiteral("meeting-participant-optional")),
-                         KCalUtils::Stringify::attendeeRole(KCalCore::Attendee::OptParticipant));
+                         KCalUtils::Stringify::attendeeRole(KCalendarCore::Attendee::OptParticipant));
     mRolesCombo->addItem(QIcon::fromTheme(QStringLiteral("meeting-observer")),
-                         KCalUtils::Stringify::attendeeRole(KCalCore::Attendee::NonParticipant));
+                         KCalUtils::Stringify::attendeeRole(KCalendarCore::Attendee::NonParticipant));
     mRolesCombo->addItem(QIcon::fromTheme(QStringLiteral("meeting-chair")),
-                         KCalUtils::Stringify::attendeeRole(KCalCore::Attendee::Chair));
+                         KCalUtils::Stringify::attendeeRole(KCalendarCore::Attendee::Chair));
 
     mRolesCombo->setWhatsThis(i18nc("@info:whatsthis",
                                     "Edits the role of the attendee."));
@@ -168,25 +166,24 @@ void SchedulingDialog::slotWeekdaysChanged()
 
 void SchedulingDialog::slotMandatoryRolesChanged()
 {
-    QSet<KCalCore::Attendee::Role> roles;
+    QSet<KCalendarCore::Attendee::Role> roles;
     for (int i = 0; i < mRolesCombo->count(); ++i) {
         if (mRolesCombo->itemCheckState(i) == Qt::Checked) {
-            roles << KCalCore::Attendee::Role(i);
+            roles << KCalendarCore::Attendee::Role(i);
         }
     }
     mResolver->setMandatoryRoles(roles);
 }
 
-void SchedulingDialog::slotRowSelectionChanged(const QModelIndex &current,
-                                               const QModelIndex &previous)
+void SchedulingDialog::slotRowSelectionChanged(const QModelIndex &current, const QModelIndex &previous)
 {
     Q_UNUSED(previous);
     if (!current.isValid()) {
         mMoveApptGroupBox->hide();
         return;
     }
-    KCalCore::Period period
-        = current.data(CalendarSupport::FreePeriodModel::PeriodRole).value<KCalCore::Period>();
+    KCalendarCore::Period period
+        = current.data(CalendarSupport::FreePeriodModel::PeriodRole).value<KCalendarCore::Period>();
     const QDate startDate = period.start().date();
 
     const int dayOfWeek = startDate.dayOfWeek();
