@@ -61,7 +61,7 @@ TemplateManagementDialog::TemplateManagementDialog(
     , m_changed(false)
 {
     QString m_type_translated = i18n(qPrintable(m_type));
-    setWindowTitle(i18n("Manage %1 Templates", m_type_translated));
+    setWindowTitle(i18nc("@title:window", "Manage %1 Templates", m_type_translated));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(
         QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -151,7 +151,7 @@ void TemplateManagementDialog::slotAddTemplate()
         m_templates.append(newTemplate);
         m_base.m_listBox->addItem(newTemplate);
         QListWidgetItem *item = m_base.m_listBox->item(count);
-        m_base.m_listBox->setItemSelected(item, true);
+        item->setSelected(true);
     }
     m_newTemplate = newTemplate;
     m_changed = true;
@@ -183,9 +183,7 @@ void TemplateManagementDialog::slotRemoveTemplate()
 
     m_templates.removeAll(item->text());
     m_base.m_listBox->takeItem(current);
-
-    m_base.m_listBox->setItemSelected(
-        m_base.m_listBox->item(qMax(current - 1, 0)), true);
+    m_base.m_listBox->item(qMax(current - 1, 0))->setSelected(true);
 
     updateButtons();
 
